@@ -2,7 +2,7 @@
 Init file for the PyNetworkD3 library.
 """
 
-from PyNetworkD3.core import ArcDiagram, Graph
+from PyNetworkD3.core import AdjacencyMatrix, ArcDiagram, Graph
 
-version_info = (0, 0, 4)
+version_info = (0, 0, 5)
 __version__ = ".".join([str(x) for x in version_info])
